import { getApp } from '@genesislcap/foundation-shell/app';
import { html, repeat, when } from '@microsoft/fast-element';
const app = getApp();
const sideNavTemplate = html `
  <zero-flyout
    position="left"
    ?closed=${(x) => !x.sideNavOpen}
    @closed=${(x) => x.toggleNavVisibility()}
    data-test-id="side-nav"
  >
    <img
      slot="title"
      src=${(x) => x.logoSrc}
      class="logo"
      part="side-nav-logo"
      data-test-id="side-nav-logo"
    />
    <slot name="menu-contents"></slot>
    <div
      slot="footer"
      class="logout-container"
      data-test-id="logout-button"
      @click=${(x) => x.logout()}
    >
      <zero-icon name="sign-out-alt"></zero-icon>
      Sign out
    </div>
  </zero-flyout>
`;
const defaultRouteNavItemsTemplate = html `
  <zero-button
    appearance="neutral-grey"
    @click=${(x) => x.navigateTo('protected')}
    data-test-id="home-button"
  >
    <zero-icon name="home"></zero-icon>
    Home
  </zero-button>
  <zero-button @click=${(x) => x.navigateTo('not-found')} data-test-id="profiles-button">
    <zero-icon name="users"></zero-icon>
    Profiles
  </zero-button>
`;
const routeNavItemsTemplate = html `
  <template>
    ${repeat((x) => x.routeNavItems, html `
        <zero-button
          appearance="neutral-grey"
          slot="routes"
          @click=${(x, c) => c.parent.navigateTo(x.routePath)}
          data-test-id="${(x) => `${x.routePath}-button`}"
        >
          ${when((x) => x.icon, html `
              <zero-icon
                name="${(x) => x.icon.name}"
                variant="${(x) => x.icon.variant}"
                size="${(x) => x.icon.size}"
              ></zero-icon>
            `)}
          ${(x, c) => c.parent.toLocalisedText(x.title)}
        </zero-button>
      `)}
  </template>
`;
/**
 * Template for Navigation class
 *
 * @remarks
 *
 * Contains the template for both the sidenav and the navigation bar
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Navigation html
 *
 * @public
 */
export const NavTemplate = html `
  ${when((x) => !x.hideSideBar, sideNavTemplate)}
  <div class="nav-listbox" data-test-id="nav-bar">
    ${app.registerElementsTarget('header-start')}
    <div class="nav-leftside">
      ${app.registerElementsTarget('nav-start')}
      ${when((x) => !x.hideSideBar, html `
          <div
            class="bars-container"
            @click=${(x) => x.toggleNavVisibility()}
            data-test-id="hamburger-menu"
          >
            <zero-icon name="bars" part="nav-visibility-icon"></zero-icon>
          </div>
        `)}
      <div class="logo-container" data-test-id="nav-bar-logo">
        <img src=${(x) => x.logoSrc} class="logo" part="logo" />
      </div>
      <slot name="routes" data-test-id="route-buttons">
        ${(x) => (x.routeNavItems ? routeNavItemsTemplate : defaultRouteNavItemsTemplate)}
      </slot>
      ${app.registerElementsTarget('nav')}
    </div>
    <div class="nav-rightside">
      ${app.registerElementsTarget('nav-end')}
      ${when((x) => x.showLuminanceToggleButton, html `
          <div
            class="icon-container"
            data-test-id="luminance-toggle-button"
            part="luminance-button"
          >
            <zero-icon
              @click=${(x) => x.luminanceIconEvent()}
              variant="regular"
              name="moon"
              part="luminance-icon"
            ></zero-icon>
          </div>
        `)}
      ${when((x) => x.showMiscToggleButton, html `
          <div class="icon-container" data-test-id="misc-toggle-button" part="misc-button">
            <zero-icon @click=${(x) => x.miscIconEvent()} name="th" part="misc-icon"></zero-icon>
          </div>
        `)}
      ${when((x) => x.showNotificationsButton, html `
          <div
            class="icon-container"
            data-test-id="notifications-button"
            part="notifications-button"
          >
            <zero-icon
              variant="regular"
              @click=${(x) => x.notificationIconEvent()}
              name="bell"
              part="notifications-icon"
            ></zero-icon>
            <slot name="notifications-icon-end"></slot>
          </div>
        `)}
      ${when((x) => x.showConnectionIndicator, html `
          <div class="connection-indicator-container" data-test-id="connection-indicator">
            <zero-connection-indicator show-label="false"></zero-connection-indicator>
          </div>
        `)}
      ${when((x) => x.showLanguageSelector && x.languageOptions, html `
          <zero-select
            class="language-selector"
            position="below"
            data-test-id="language-selector"
            part="language-selector"
            @change="${(x, c) => x.changeLanguage(c.event)}"
          >
            ${repeat((x) => x.languageOptions.availableLanguages, html `
                <zero-option
                  value="${(x) => x}"
                  ?selected="${(x, c) => x === c.parent.languageOptions.selectedLanguage}"
                >
                  ${(x) => x.toUpperCase()}
                </zero-option>
              `)}
          </zero-select>
        `)}

      <zero-button appearance="neutral-grey" data-test-id="user-button">
        <zero-icon name="user-circle"></zero-icon>
        ${(x) => x.userName}
      </zero-button>
    </div>
    ${app.registerElementsTarget(['header', 'header-end'])}
  </div>
`;
/**
 * Top level template for Navigation class
 *
 * @remarks
 *
 * Dynamic template which wraps the code in a provider
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Navigation html
 *
 * @internal
 */
export const DynamicTemplate = html `
  <div class="dynamic-template">${(x) => x.selectTemplate()}</div>
`;
/**
 * Loading template for the Navigation class
 *
 * @remarks
 *
 * Template used to indicate loading to the user
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Loading html
 *
 * @internal
 */
export const LoadingTemplate = html `
  ...
`;
/**
 * Render template for the Navigation class
 *
 * @remarks
 *
 * Template used when the class has finished loading
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Main html
 *
 * @internal
 */
export const MainTemplate = html `
  ${NavTemplate}
`;
